package es.geeknekodroid.divertiletras;

import android.content.Context;
import android.database.Cursor;
import android.database.SQLException;
import android.database.sqlite.SQLiteCursor;
import android.database.sqlite.SQLiteCursorDriver;
import android.database.sqlite.SQLiteDatabase;
import android.database.sqlite.SQLiteOpenHelper;
import android.database.sqlite.SQLiteQuery;
import android.util.Log;

public class Database extends SQLiteOpenHelper 
{
	private static final String DATABASE_NAME = "TREN";
	private static final int DATABASE_VERSION = 1;
	private final Context mContext;
	
	public Database(Context context) 
	  {
	      super(context, DATABASE_NAME, null, DATABASE_VERSION);
	      this.mContext = context;
		}

	@Override
	public void onCreate(SQLiteDatabase db) 
	{
		String[] sqlDefinition = mContext.getString(R.string.db_definition).split("\n");
		String[] sqlData = mContext.getString(R.string.db_data).split("\n");
		db.beginTransaction();
		try
		{
	     	//Crea las tablas 
			for(String s : sqlDefinition)
			{
				if(s.trim().length()>0)
					db.execSQL(s);
			}
			//e introduce los datos
			for(String s : sqlData)
			{
				if(s.trim().length()>0)
					db.execSQL(s);
			}
			db.setTransactionSuccessful();
		}
		catch(SQLException e)
		{
			Log.e("Database error", e.toString());
			throw e;
		}
		finally
		{
			db.endTransaction();
		}		
	}

	@Override
	public void onUpgrade(SQLiteDatabase db, int oldVersion, int newVersion) 
	{
		db.execSQL("DROP TABLE IF EXISTS Tren");
		onCreate(db);
	}

	public static class TrainCursor extends SQLiteCursor
	{
		private static final String QUERY = 
				"SELECT _id, palabra, opcion1, opcion2, opcion3, opcion4, nivel" + 
				" FROM Tren ";
	
		private TrainCursor(SQLiteDatabase db, SQLiteCursorDriver driver,String editTable, SQLiteQuery query)
		{
			super(db, driver, editTable, query);
		}
		
		private static class Factory implements SQLiteDatabase.CursorFactory
		{
			@Override
			public Cursor newCursor(SQLiteDatabase db, SQLiteCursorDriver driver, String editTable, SQLiteQuery query) 
			{
				return new TrainCursor(db, driver, editTable, query);
			}
	    }

		public int getColId()
		{
			return getInt(getColumnIndexOrThrow("_id"));
		}
		public String getColPalabra()
		{
			return getString(getColumnIndexOrThrow("palabra"));
		}
		public String getColOpcion1()
		{
			return getString(getColumnIndexOrThrow("opcion1"));
		}
		public String getColOpcion2()
		{
			return getString(getColumnIndexOrThrow("opcion2"));
		}
		public String getColOpcion3()
		{
			return getString(getColumnIndexOrThrow("opcion3"));
		}
		public String getColOpcion4()
		{
			return getString(getColumnIndexOrThrow("opcion4"));
		}
		public int getColNivel()
		{
			return getInt(getColumnIndexOrThrow("nivel"));
		}
	}
	
	public TrainCursor getAllTrains()
	{
		String sql = TrainCursor.QUERY + ";";
		SQLiteDatabase d = getReadableDatabase();
		TrainCursor c = (TrainCursor) d.rawQueryWithFactory(new TrainCursor.Factory(), sql, null, null);
		c.moveToFirst();
		return c;
	}
	public TrainCursor getTrain(int id)
	{
		String sql = TrainCursor.QUERY + "WHERE _id = " + id + ";";
		SQLiteDatabase d = getReadableDatabase();
		TrainCursor c = (TrainCursor) d.rawQueryWithFactory(new TrainCursor.Factory(), sql, null, null);
		c.moveToFirst();
		return c;
	}
}
