package es.geeknekodroid.divertiletras;

import java.io.IOException;

import android.app.AlertDialog;
import android.content.DialogInterface;
import android.content.DialogInterface.OnShowListener;
import android.content.Intent;
import android.graphics.Typeface;
import android.media.MediaPlayer;
import android.os.Bundle;
import android.support.v7.app.ActionBarActivity;
import android.view.LayoutInflater;
import android.view.Menu;
import android.view.MenuInflater;
import android.view.MenuItem;
import android.view.View;
import android.view.View.OnClickListener;
import android.widget.Button;
import android.widget.LinearLayout;
import android.widget.TextView;

public class MainActivity extends ActionBarActivity
{
	Typeface font;
	LinearLayout b1, b2;
	MediaPlayer mp;
	
	
	@Override
	protected void onCreate(Bundle savedInstanceState) 
	{
		super.onCreate(savedInstanceState);
		setContentView(R.layout.activity_main);
		
		font = Typeface.createFromAsset(getAssets(), "fonts/pacifico.ttf");
		
		//musica
		mp = MediaPlayer.create(this, R.raw.runamok);
		mp.setLooping(true);
		mp.start();
		
		//Acceso a los juegos
		b1 = (LinearLayout)findViewById(R.id.boton1);
		b1.setOnClickListener(new OnClickListener() {
			
			@Override
			public void onClick(View v) {
				openMercanciaConfirmation(v);
				
			}
		});
		b2 = (LinearLayout)findViewById(R.id.boton2);
		b2.setOnClickListener(new OnClickListener() 
		{
			@Override
			public void onClick(View v) 
			{
				openMemoConfirmation(v);
			}
		});
	}
	
	@Override
	public boolean onCreateOptionsMenu(Menu menu) 
	{
		MenuInflater inflater = getMenuInflater();
	    inflater.inflate(R.menu.main, menu);
	    return super.onCreateOptionsMenu(menu);
	}
	
	@Override
	public boolean onOptionsItemSelected(MenuItem item) 
	{
	    switch (item.getItemId()) 
	    {   
	        //Informacin sobre la aplicacin
	        case R.id.action_about:
	        	openAbout(null);
	        	return true;
	        
	        default:
	            return super.onOptionsItemSelected(item);
	    }
	}

	//Dialogo de confirmacin para abrir el juego La mercanca perdida
	public void openMercanciaConfirmation(View v)
	{
		LayoutInflater factory = LayoutInflater.from(this);
	    final View image = factory.inflate(R.layout.mercancia_dialog, null);
	   
	    //Titulo del dialog
	    TextView title = new TextView(this);
	    title.setText(getResources().getString(R.string.mercancia));
	    title.setTypeface(font);
	    title.setTextSize(25);
	    title.setPadding(10, 0, 0, 0);
	    title.setTextColor(getResources().getColor(R.color.azul)); 
		
		AlertDialog.Builder builder = new AlertDialog.Builder(this);
		builder.setCustomTitle(title)
        .setView(image)
		.setPositiveButton(R.string.jugar, new DialogInterface.OnClickListener() 
        {
            public void onClick(DialogInterface dialog, int id) 
            {
            	openMercancia(null);
            }
        })
        .setNegativeButton(R.string.volver, null);

		AlertDialog customDialog = builder.create();
		customDialog.setOnShowListener(new OnShowListener() {
			@Override
			public void onShow(DialogInterface dialog) {
				Button positiveButton = ((AlertDialog) dialog).getButton(AlertDialog.BUTTON_POSITIVE);
				positiveButton.setTextSize(25);
				positiveButton.setTypeface(font);
				Button negativeButton = ((AlertDialog) dialog).getButton(AlertDialog.BUTTON_NEGATIVE);
				negativeButton.setTextSize(25);
				negativeButton.setTypeface(font);
			}
		});
		customDialog.show();
	}

	//Dialogo de confirmacin para abrir el juego Memo de letras
	public void openMemoConfirmation(View v)
	{
		 //Titulo del dialog
	    TextView title = new TextView(this);
	    title.setText(getResources().getString(R.string.memo));
	    title.setTypeface(font);
	    title.setTextSize(25);
	    title.setPadding(10, 0, 0, 0);
	    title.setTextColor(getResources().getColor(R.color.azul)); 
	    
		AlertDialog.Builder builder = new AlertDialog.Builder(this);
		builder.setCustomTitle(title)
		.setMessage("Prximamente")
		.setNegativeButton(R.string.volver, null);
		
		AlertDialog customDialog = builder.create();
		customDialog.setOnShowListener(new OnShowListener() {
			@Override
			public void onShow(DialogInterface dialog) {
				Button negativeButton = ((AlertDialog) dialog).getButton(AlertDialog.BUTTON_NEGATIVE);
				negativeButton.setTextSize(25);
				negativeButton.setTypeface(font);
			}
		});
		customDialog.show();
	}
	
	public void openMercancia(View v)
	{
		Intent i = new Intent(this, Mercancia.class);
		startActivity(i);
	}
	
	public void openAbout(View v)
	{
		Intent i = new Intent(this, Acerca.class);
		startActivity(i);
	}
		
	@Override
	protected void onResume() 
	{
		super.onResume();
		mp.start();
	}
	
	@Override
	protected void onPause() 
	{
		mp.stop();
		super.onPause();
	}
	
	@Override
	protected void onRestart()
	{
		super.onRestart();
		try {
			mp.prepare();
		} catch (IllegalStateException | IOException e) 
		{
			e.printStackTrace();
		}
		mp.start();
	}
}
